@@ -23,8 +23,8 @@ def json_to_csv(data_array, io_format=False):
     """
     Converts a json array into a csv file
 
-    :param data_array: JSON dict
-    :type data_array: dict
+    :param data_array: JSON list
+    :type data_array: list
     :param io_format: Flag to return IO format
     :type io_format: bool, optional
     :return:
